@@ -1,13 +1,13 @@
 package Text::MiniTmpl;
-
+use 5.012000;
 use warnings;
 use strict;
+use utf8;
 use Carp;
 
-use version; our $VERSION = qv('1.1.6');    # REMINDER: update Changes
+our $VERSION = 'v2.0.0';
 
-# REMINDER: update dependencies in Makefile.PL
-use Perl6::Export::Attrs;
+use Export::Attrs;
 use JSON::XS qw( encode_json );
 use URI::Escape qw();
 use HTML::Entities qw();
@@ -79,7 +79,7 @@ sub tmpl2code :Export {
           : $s=~/\G      ( (?>[^<&@\#^]*) .*? ) (?=<!--&|&~|@~|\#~|\^~|\z)/xmsgc
                 ? q{$}.__PACKAGE__."::__ .= \"\Q$1\E\";"
           : last;
-        $line += $1 =~ tr/\n//;
+        $line += $1 =~ tr/\n//; ## no critic (ProhibitCaptureWithoutTest)
         $e .= "\n#line $line \"$path\"\n";
     }
     $e .= '; return \$'.__PACKAGE__.'::__ }';
@@ -121,6 +121,11 @@ __END__
 Text::MiniTmpl - Compile and render templates
 
 
+=head1 VERSION
+
+This document describes Text::MiniTmpl version v2.0.0
+
+
 =head1 SYNOPSIS
 
     use Text::MiniTmpl qw( render );
@@ -180,7 +185,7 @@ You can disable it using raw(1) (see below) to get more speed.
 =head2 Source Filters support
 
 Probably not all filters will work inside templates - keep in mind filter
-will see autogenerated (by tmpl2code()) perl function's code instead of
+will see auto-generated (by tmpl2code()) perl function's code instead of
 plain template text. See `perldoc perlfilter` for more details.
 
 Example:
@@ -402,71 +407,63 @@ render it on each run - no caches used at all (except HDD files caching by OS).
 =back
 
 
-=head1 BUGS AND LIMITATIONS
-
-No bugs have been reported.
-
-
 =head1 SUPPORT
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Text-MiniTmpl>.
-I will be notified, and then you'll automatically be notified of progress
-on your bug as I make changes.
+=head2 Bugs / Feature Requests
 
-You can also look for information at:
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/powerman/perl-Text-MiniTmpl/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software. The code repository is available for
+public review and contribution under the terms of the license.
+Feel free to fork the repository and submit pull requests.
+
+L<https://github.com/powerman/perl-Text-MiniTmpl>
+
+    git clone https://github.com/powerman/perl-Text-MiniTmpl.git
+
+=head2 Resources
 
 =over
 
-=item * RT: CPAN's request tracker
+=item * MetaCPAN Search
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Text-MiniTmpl>
+L<https://metacpan.org/search?q=Text-MiniTmpl>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/dist/Text-MiniTmpl>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
 L<http://annocpan.org/dist/Text-MiniTmpl>
 
-=item * CPAN Ratings
+=item * CPAN Testers Matrix
 
-L<http://cpanratings.perl.org/d/Text-MiniTmpl>
+L<http://matrix.cpantesters.org/?dist=Text-MiniTmpl>
 
-=item * Search CPAN
+=item * CPANTS: A CPAN Testing Service (Kwalitee)
 
-L<http://search.cpan.org/dist/Text-MiniTmpl/>
+L<http://cpants.cpanauthors.org/dist/Text-MiniTmpl>
 
 =back
 
 
 =head1 AUTHOR
 
-Alex Efros  C<< <powerman-asdf@ya.ru> >>
+Alex Efros E<lt>powerman@cpan.orgE<gt>
 
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010,2014 Alex Efros <powerman-asdf@ya.ru>.
+This software is Copyright (c) 2007-2014 by Alex Efros E<lt>powerman@cpan.orgE<gt>.
 
-This program is distributed under the MIT (X11) License:
-L<http://www.opensource.org/licenses/mit-license.php>
+This is free software, licensed under:
 
-Permission is hereby granted, free of charge, to any person
-obtaining a copy of this software and associated documentation
-files (the "Software"), to deal in the Software without
-restriction, including without limitation the rights to use,
-copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following
-conditions:
+  The MIT (X11) License
 
-The above copyright notice and this permission notice shall be
-included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
-EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
-OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
-NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
-OTHER DEALINGS IN THE SOFTWARE.
 
+=cut
